.. _apps-rpc:

============================
JSON-RPC
============================

.. automodule:: pulsar.apps.rpc


API
===========

RpcHandler
~~~~~~~~~~~~~~

.. autoclass:: RpcHandler
   :members:
   :member-order: bysource
   
   
RpcMiddleware
~~~~~~~~~~~~~~~~

.. autoclass:: RpcMiddleware
   :members:
   :member-order: bysource
   
   
JSON RPC
~~~~~~~~~~~~~~~~

.. autoclass:: JSONRPC
   :members:
   :member-order: bysource
   
   
JsonProxy
~~~~~~~~~~~~~~~~

.. autoclass:: JsonProxy
   :members:
   :member-order: bysource
   
   
FromApi
~~~~~~~~~~~~~~~~~

.. autofunction:: FromApi


Server Commands
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: PulsarServerCommands
   :members:
   :member-order: bysource   